@@ -1,7 +1,7 @@
 from django.contrib import admin
 
-from .models import Log, Service
-
+from .models import Log, Service, Notification
+from ftp_deploy.server.forms import NotificationForm
 
 class ServiceAdmin(admin.ModelAdmin):
 
@@ -28,7 +28,7 @@ class ServiceAdmin(admin.ModelAdmin):
 
 class LogAdmin(admin.ModelAdmin):
     list_display = ('id', 'created', 'user', 'status_message_html', 'status')
-    readonly_fields = ('service', 'created', 'user', 'status')
+    readonly_fields = ('service', 'created', 'user', 'status','status_message_html')
     exclude = ('payload',)
 
     def has_add_permission(self, request):
@@ -39,5 +39,16 @@ class LogAdmin(admin.ModelAdmin):
     status_message_html.allow_tags = True
     status_message_html.short_description = 'Status Message'
 
+
+
+class NotificationAdmin(admin.ModelAdmin):
+    form = NotificationForm
+    list_display = ('name',)
+
+ 
+
+admin.site.register(Notification, NotificationAdmin)
+
+
 admin.site.register(Service, ServiceAdmin)
 admin.site.register(Log, LogAdmin)
