@@ -11,11 +11,12 @@ from django.views.decorators.csrf import csrf_exempt
 
 from .models import Log, Service
 from .conf import *
-from .utils.core import absolute_url
+from .utils.core import absolute_url, LockError
 from .utils.ftp import ftp_connection
 from .utils.email import notification_success, notification_fail
 from .utils.curl import curl_connection
 
+
 class DeployView(View):
 
     """Main view receive POST Hook from repository"""
@@ -42,27 +43,33 @@ class DeployView(View):
 
     def post(self, request, *args, **kwargs):
 
-        json_string = request.POST['payload'].decode('string_escape').replace('\n', '')
-        self.data = json.loads(json_string)
+        self.json_string = request.POST['payload'].decode('string_escape').replace('\n', '')
+        self.data = json.loads(self.json_string)
         last_commit = len(self.data['commits']) - 1
 
+
         if self.data['commits'][last_commit]['branch'] == self.bitbucket_branch:
+            self.log = Log()
+            self.log.payload = self.json_string
+            self.log.service = self.service
+            self.log.save()
 
             try:
-                self.log = Log()
-                self.log.payload = json_string
-
                 self.ftp = ftp_connection(self.ftp_host, self.ftp_username, self.ftp_password, self.ftp_path)
+
+                if self.service.lock:
+                    raise LockError()
+
+                self.service.check = False
+                self.service.lock = True
+                self.service.save()
+
                 self.ftp.connect()
 
+            except LockError, e:
+                self.set_fail(request, 'Service Locked', e)
             except Exception, e:
-                self.log.user = 'FTP Connection'
-                self.log.status_message = e
-                self.log.service = self.service
-                self.log.status = False
-                self.service.status = False
-                self.status = 500
-                notification_fail(absolute_url(request).build(), self.service, json_string, e)
+                self.set_fail(request, 'FTP Connection', e)
             else:
                 try:
                     curl = curl_connection(self.bitbucket_username, self.bitbucket_password)
@@ -93,25 +100,28 @@ class DeployView(View):
                                 os.unlink(temp_file.name)
 
                 except Exception, e:
-                    self.log.user = self.data['user']
-                    self.log.status_message = e
-                    self.log.service = self.service
-                    self.log.status = False
-                    self.service.status = False
-                    self.status = 500
-                    notification_fail(absolute_url(request).build(), self.service, json_string, e)
+                    self.set_fail(request, self.data['user'], e)
                 else:
                     self.log.user = self.data['user']
-                    self.log.service = self.service
                     self.log.status = True
                     self.log.save()
-                    notification_success(absolute_url(request).build(), self.service, json_string)
+                    notification_success(absolute_url(request).build(), self.service, self.json_string)
                 finally:
                     curl.close()
 
             finally:
                 self.ftp.quit()
-                self.log.save()
+                self.service.lock = False
+                self.service.check = True
                 self.service.save()
 
         return HttpResponse(status=self.status)
+
+    def set_fail(self, request, user, message):
+        self.log.user = user
+        self.log.status_message = message
+        self.log.status = False
+        self.log.save()
+        self.service.status = False
+        self.status = 500
+        notification_fail(absolute_url(request).build(), self.service, self.json_string, message)
